@@ -11,8 +11,9 @@ namespace KScreen
 {
 WaylandOutputManagement::WaylandOutputManagement(struct ::wl_registry *registry, int id, int version)
     : QObject()
-    , QtWayland::kde_output_management_v2(registry, id, version)
+    , QtWayland::kde_output_management_v2()
 {
+    init(registry, id, version);
 }
 
 WaylandOutputConfiguration *WaylandOutputManagement::createConfiguration()
@@ -36,29 +37,4 @@ void WaylandOutputConfiguration::kde_output_configuration_v2_failed()
     Q_EMIT failed();
 }
 
-WaylandOutputOrder::WaylandOutputOrder(struct ::wl_registry *registry, int id, int version)
-    : QtWayland::kde_output_order_v1(registry, id, version)
-{
-}
-
-WaylandOutputOrder::~WaylandOutputOrder()
-{
-}
-
-QVector<QString> WaylandOutputOrder::order() const
-{
-    return m_outputOrder;
-}
-
-void WaylandOutputOrder::kde_output_order_v1_output(const QString &output_name)
-{
-    m_pendingOutputOrder.push_back(output_name);
-}
-
-void WaylandOutputOrder::kde_output_order_v1_done()
-{
-    m_outputOrder = m_pendingOutputOrder;
-    Q_EMIT outputOrderChanged(m_pendingOutputOrder);
-    m_pendingOutputOrder.clear();
-}
 }
